@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: An EXPERIMENTAL subclass of <Exporter::Extensible>, which helps create easy-to-extend modules that export symbols
-our $VERSION = '0.200000';
+our $VERSION = '0.200001';
 
 use Exporter::Extensible -exporter_setup => 1;
 
@@ -14,6 +14,11 @@ sub xtags : Export {
   Exporter::Handy::Util::xtags({ sig => ':' }, @_)
 }
 
+sub expand_xtags : Export {
+  require Exporter::Handy::Util;
+  Exporter::Handy::Util::expand_xtags(@_)
+}
+
 
 # PRAGMATA
 # Remember: Pragmas effect the current compilation context.
@@ -105,7 +110,7 @@ Exporter::Handy - An EXPERIMENTAL subclass of <Exporter::Extensible>, which help
 
 =head1 VERSION
 
-version 0.200000
+version 0.200001
 
 =head1 SYNOPSIS
 
