@@ -1,15 +1,14 @@
 package Exporter::Handy::Util;
 
 # ABSTRACT: Routines useful when exporting symbols thru Exporter and friends
-our $VERSION = '0.200000';
+our $VERSION = '0.200001';
 
-use v5.14;
+use utf8;
 use strict;
 use warnings;
 
-use Data::Printer;
-
-use List::Util qw( pairs unpairs uniq );
+# Automatically fall back to pure perl for older versions of List::Util (circa Perl version < 5.20)
+use List::Util::MaybeXS qw( pairs unpairs uniq );
 use Exporter::Extensible -exporter_setup => 1;
 
 export(qw(
@@ -182,7 +181,7 @@ Exporter::Handy::Util - Routines useful when exporting symbols thru Exporter and
 
 =head1 VERSION
 
-version 0.200000
+version 0.200001
 
 =head1 SYNOPSIS
 
